@@ -43,12 +43,12 @@ from airflow.configuration import conf
 from airflow.executors import workloads
 from airflow.models.dag import DAG
 from airflow.models.taskinstance import TaskInstance
-from airflow.models.taskinstancekey import TaskInstanceKey
-from airflow.providers.common.compat.sdk import AirflowException, AirflowTaskTimeout
+from airflow.providers.common.compat.sdk import AirflowException, AirflowTaskTimeout, TaskInstanceKey
 from airflow.providers.standard.operators.bash import BashOperator
 from airflow.utils.state import State
 
 from tests_common.test_utils import db
+from tests_common.test_utils.taskinstance import create_task_instance
 from tests_common.test_utils.version_compat import AIRFLOW_V_3_0_PLUS
 
 logger = logging.getLogger(__name__)
@@ -215,14 +215,10 @@ class TestCeleryExecutor:
             # fake_execute_command takes no arguments while execute_workload takes 1,
             # which will cause TypeError when calling task.apply_async()
             executor = celery_executor.CeleryExecutor()
-            task = BashOperator(
-                task_id="test",
-                bash_command="true",
-                dag=DAG(dag_id="dag_id"),
-                start_date=datetime.now(),
-            )
+            with DAG(dag_id="dag_id"):
+                task = BashOperator(task_id="test", bash_command="true", start_date=datetime.now())
             if AIRFLOW_V_3_0_PLUS:
-                ti = TaskInstance(task=task, run_id="abc", dag_version_id=uuid6.uuid7())
+                ti = create_task_instance(task=task, run_id="abc", dag_version_id=uuid6.uuid7())
             else:
                 ti = TaskInstance(task=task, run_id="abc")
             workload = workloads.ExecuteTask.model_construct(
@@ -254,14 +250,10 @@ class TestCeleryExecutor:
             assert executor.task_publish_retries == {}
             assert executor.task_publish_max_retries == 3, "Assert Default Max Retries is 3"
 
-            task = BashOperator(
-                task_id="test",
-                bash_command="true",
-                dag=DAG(dag_id="id"),
-                start_date=datetime.now(),
-            )
+            with DAG(dag_id="id"):
+                task = BashOperator(task_id="test", bash_command="true", start_date=datetime.now())
             if AIRFLOW_V_3_0_PLUS:
-                ti = TaskInstance(task=task, run_id="abc", dag_version_id=uuid6.uuid7())
+                ti = create_task_instance(task=task, run_id="abc", dag_version_id=uuid6.uuid7())
             else:
                 ti = TaskInstance(task=task, run_id="abc")
             workload = workloads.ExecuteTask.model_construct(
